#!/bin/sh

PKG_NAME="bc"
PKG_VER="1.06"
PKG_REV="1"
PKG_DESC="An arbitary-precision numeric processing language"
PKG_CAT="core"
PKG_DEPS=""

download() {
	# download the sources tarball
	if [ ! -f $PKG_NAME-$PKG_VER.tar.gz ]
	then
		download_file ftp://ftp.gnu.org/gnu/$PKG_NAME/$PKG_NAME-$PKG_VER.tar.gz
		[ $? -ne 0 ] && return 1
	fi

	# download the Arch Linux build fix
	if [ ! -f build-fix.patch ]
	then
		wget -O build-fix.patch 'http://projects.archlinux.org/svntogit/packages.git/plain/trunk/build-fix.patch?h=packages/bc'
		[ $? -ne 0 ] && return 1
	fi

	return 0
}

build() {
	# extract the sources tarball
	tar -xzvf $PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# patch the sources
	patch -p1 < ../build-fix.patch
	[ $? -ne 0 ] && return 1

	# generate a new configure script
	autoconf
	[ $? -ne 0 ] && return 1

	# configure the package
	./configure $AUTOTOOLS_BASE_OPTS \
	            --without-pkg \
	            --without-libedit \
	            --without-readline
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# install the list of authors
	install -D -m644 AUTHORS $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/AUTHORS
	[ $? -ne 0 ] && return 1

	return 0
}
