#!/bin/sh

PKG_NAME="dbus"
PKG_VER="1.2.28"
PKG_REV="1"
PKG_DESC="A message bus system for IPC"
PKG_CAT="core"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.gz ] && return 0
	# download the sources tarball
	download_file http://dbus.freedesktop.org/releases/dbus/$PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xzvf $PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# configure the package
	./configure $AUTOTOOLS_BASE_OPTS \
	            --disable-static \
	            --enable-shared \
	            --disable-verbose-mode \
	            --disable-gcov \
	            --disable-selinux \
	            --disable-libaudit \
	            --enable-inotify \
	            --disable-dnotify \
	            --disable-userdb-cache \
	            --with-xml=expat \
	            --with-system-pid-file=/$VAR_DIR/run/dbus/pid \
	            --with-system-socket=/$VAR_DIR/run/dbus/system_bus_socket \
	            --with-x
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# create the variable data directories
	mkdir -p $INSTALL_DIR/$VAR_DIR/run/dbus /$VAR_DIR/lib/dbus
	[ $? -ne 0 ] && return 1

	# add an init script
	mkdir -p $INSTALL_DIR/$INIT_SCRIPT_DIR
	[ $? -ne 0 ] && return 1
	cat << END > $INSTALL_DIR/$INIT_SCRIPT_DIR/dbus
#!/bin/dash
case "\$1" in
	start)
		echo -n "Starting D-Bus ..."
		[ -f /$VAR_DIR/run/dbus/pid ] && rm -f /$VAR_DIR/run/dbus/pid
		dbus-daemon --system --fork
	 	dbus-uuidgen > /$VAR_DIR/lib/dbus/machine-id
	 	echo " done"
		;;
	stop)
		echo -n "Stopping D-Bus ..."
		killall dbus-daemon
		echo " done"
		;;
	restart)
		"\$0" stop
		"\$0" start
		;;

	*)
		echo "dbus {start|stop|restart}"
		exit 1
		;;

esac
END
	chmod 755 $INSTALL_DIR/$INIT_SCRIPT_DIR/dbus
	[ $? -ne 0 ] && return 1

	# install the license and the list of authors
	install -D -m644 COPYING $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/COPYING
	[ $? -ne 0 ] && return 1
	install -D -m644 AUTHORS $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/AUTHORS
	[ $? -ne 0 ] && return 1

	return 0
}
