#!/bin/sh

PKG_NAME="dhcpcd"
PKG_VER="5.2.12"
PKG_REV="1"
PKG_DESC="A RFC2131-compliant DHCP client"
PKG_CAT="core"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.bz2 ] && return 0
	# download the sources tarball
	download_file http://roy.marples.name/downloads/dhcpcd/$PKG_NAME-$PKG_VER.tar.bz2
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xjvf $PKG_NAME-$PKG_VER.tar.bz2
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# configure the package
	./configure --disable-debug \
	            --prefix=/$BASE_INSTALL_PREFIX \
	            --sysconfdir=/$CONF_DIR \
	            --bindir=/$BIN_DIR \
	            --sbindir=/$SBIN_DIR \
	            --libexecdir=/$LIBEXEC_DIR \
	            --statedir=/$VAR_DIR \
	            --dbdir=/$VAR_DIR/lib/$PKG_NAME \
	            --rundir=/$VAR_DIR/run \
	            --mandir=/$MAN_DIR \
	            --with-ccopts="$CFLAGS" \
	            --build=$BUILD_TARGET \
	            --libdir=/$LIB_DIR \
	            --includedir=/$INCLUDE_DIR
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# create the variable data directory
	mkdir -p $INSTALL_DIR/$VAR_DIR/lib/$PKG_NAME
	[ $? -ne 0 ] && return 1

	# create backwards-compatibility symlinks
	if [ "sbin" != "$SBIN_DIR" ]
	then
		mkdir $INSTALL_DIR/sbin
		[ $? -ne 0 ] && return 1
		ln -s ../$SBIN_DIR/dhcpcd $INSTALL_DIR/sbin/dhcpcd
		[ $? -ne 0 ] && return 1
	fi

	if [ "usr/sbin" != "$SBIN_DIR" ]
	then
		mkdir -p $INSTALL_DIR/usr/sbin
		[ $? -ne 0 ] && return 1
		ln -s ../../$SBIN_DIR/dhcpcd $INSTALL_DIR/usr/sbin/dhcpcd
		[ $? -ne 0 ] && return 1
	fi

	return 0
}
