#!/bin/sh

PKG_NAME="dialog"
PKG_VER="1.1-20111020"
PKG_REV="1"
PKG_DESC="A script interpreter which provides ncurses widgets"
PKG_CAT="core"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tgz ] && return 0
	# download the sources tarball
	download_file ftp://invisible-island.net/dialog/$PKG_NAME-$PKG_VER.tgz
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xzvf $PKG_NAME-$PKG_VER.tgz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# generate a new configure script
	autoconf
	[ $? -ne 0 ] && return 1

	# configure the package
	./configure $AUTOTOOLS_BASE_OPTS \
	            --disable-echo \
	            --enable-nls \
	            --disable-trace \
	            --disable-extras \
	            --enable-rc-file \
	            --disable-Xdialog \
	            --enable-widec
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1
	
	# install the configuration file
	install -D -m644 samples/slackware.rc $INSTALL_DIR/$CONF_DIR/dialogrc
	[ $? -ne 0 ] && return 1
	
	# create backwards-compatibility symlinks
	if [ "usr/bin" != "$BIN_DIR" ]
	then
		mkdir -p $INSTALL_DIR/usr/bin
		[ $? -ne 0 ] && return 1
		ln -s ../../$BIN_DIR/dialog $INSTALL_DIR/usr/bin/dialog
		[ $? -ne 0 ] && return 1
	fi

	if [ "bin" != "$BIN_DIR" ]
	then
		mkdir -p $INSTALL_DIR/bin
		[ $? -ne 0 ] && return 1
		ln -s ../$BIN_DIR/dialog $INSTALL_DIR/bin/dialog
		[ $? -ne 0 ] && return 1
	fi

	# install the license
	install -D -m644 package/debian/copyright \
	                 $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/copyright
	[ $? -ne 0 ] && return 1

	return 0
}
