#!/bin/sh

PKG_NAME="file"
PKG_VER="5.10"
PKG_REV="1"
PKG_DESC="A file type guesser"
PKG_CAT="core"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.gz ] && return 0
	# download the sources tarball
	download_file ftp://ftp.astron.com/pub/file/$PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xzvf $PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# configure the package
	./configure $AUTOTOOLS_BASE_OPTS \
	            --enable-shared \
	            --disable-static
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# create backwards-compatibility symlinks
	if [ "usr/bin" != "$BIN_DIR" ]
	then
		mkdir -p $INSTALL_DIR/usr/bin
		[ $? -ne 0 ] && return 1
		ln -s ../../$BIN_DIR/file $INSTALL_DIR/usr/bin/file
		[ $? -ne 0 ] && return 1
	fi

	if [ "usr/share" != "$SHARE_DIR" ]
	then
		mkdir -p $INSTALL_DIR/usr/share/misc
		[ $? -ne 0 ] && return 1
		ln -s ../../$SHARE_DIR/misc/magic.mgc $INSTALL_DIR/usr/share/misc/magic.mgc
		[ $? -ne 0 ] && return 1
	fi

	# install the license
	install -D -m644 COPYING $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/COPYING
	[ $? -ne 0 ] && return 1

	return 0
}
