#!/bin/sh

PKG_NAME="mingetty"
PKG_VER="1.08"
PKG_REV="1"
PKG_DESC="Terminal manager with an automatic-login feature"
PKG_CAT="core"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.gz ] && return 0
	# download the sources tarball
	download_file http://downloads.sourceforge.net/project/mingetty/mingetty/$PKG_VER/$PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xzvf $PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# configure the package
	sed -e s~'^CC=.*'~'CC=cc'~ \
	    -e s~'^CFLAGS=.*'~"CFLAGS=$CFLAGS -D_GNU_SOURCE"~ \
	    -e s~'^MANDIR=.*'~"MANDIR=/$MAN_DIR/man8"~ \
	    -e s~'^SBINDIR=.*'~"SBINDIR=/$SBIN_DIR"~ \
	    -i Makefile
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	mkdir -p $INSTALL_DIR/$MAN_DIR/man8 $INSTALL_DIR/$SBIN_DIR
	[ $? -ne 0 ] && return 1
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# create a backwards-compatibility symlink
	if [ "sbin" != "$SBIN_DIR" ]
	then
		mkdir $INSTALL_DIR/sbin
		[ $? -ne 0 ] && return 1
		ln -s ../$SBIN_DIR/mingetty $INSTALL_DIR/sbin/mingetty
		[ $? -ne 0 ] && return 1
	fi

	return 0
}
