#!/bin/sh

PKG_NAME="shared-mime-info"
PKG_VER="1.0"
PKG_REV="1"
PKG_DESC="A database of common file types"
PKG_CAT="core"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.xz ] && return 0
	# download the sources tarball
	download_file http://freedesktop.org/~hadess/$PKG_NAME-$PKG_VER.tar.xz
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xJvf $PKG_NAME-$PKG_VER.tar.xz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# configure the package
	./configure $AUTOTOOLS_BASE_OPTS \
	            --disable-update-mimedb
	[ $? -ne 0 ] && return 1

	# build the package
	make
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# create a backwards-compatibility symlink
	if [ "usr/share" != "$SHARE_DIR" ]
	then
		mkdir -p $INSTALL_DIR/usr/share
		[ $? -ne 0 ] && return 1
		ln -s ../../$SHARE_DIR/mime $INSTALL_DIR/usr/share/mime
		[ $? -ne 0 ] && return 1
	fi
	
	# add the post-installation script
	echo -n "#!/bin/sh

echo \"Updating the MIME database\"
update-mime-database ./$SHARE_DIR/mime" > $INSTALL_DIR/post_install.sh 
	[ $? -ne 0 ] && return 1
	chmod 755 $INSTALL_DIR/post_install.sh
	[ $? -ne 0 ] && return 1

	# add the post-removal script
	echo -n "#!/bin/sh

rm -rf ./$SHARE_DIR/mime" > $INSTALL_DIR/post_uninstall.sh
	[ $? -ne 0 ] && return 1
	chmod 755 $INSTALL_DIR/post_uninstall.sh
	[ $? -ne 0 ] && return 1
		
	return 0
}
