#!/bin/sh

PKG_NAME="yad"
PKG_VER="0.16.3"
PKG_REV="1"
PKG_DESC="Tool for displaying graphical dialogs from shell scripts"
PKG_CAT="core"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.xz ] && return 0
	# download the sources tarball
	download_file http://yad.googlecode.com/files/$PKG_NAME-$PKG_VER.tar.xz
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xJvf $PKG_NAME-$PKG_VER.tar.xz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# configure the package
	./configure $AUTOTOOLS_BASE_OPTS \
	            --disable-icon-browser \
	            --with-rgb="$(find /usr -name rgb.txt | head -n 1)"
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# keep only one icon
	mkdir -p $INSTALL_DIR/$PIXMAP_DIR
	[ $? -ne 0 ] && return 1
	mv $INSTALL_DIR/$SHARE_DIR/icons/hicolor/48x48/apps/yad.png $INSTALL_DIR/$PIXMAP_DIR
	[ $? -ne 0 ] && return 1
	rm -rf $INSTALL_DIR/$SHARE_DIR/icons
	[ $? -ne 0 ] && return 1

	# create a backwards-compatibility symlink for Zenity
	ln -s yad $INSTALL_DIR/$BIN_DIR/zenity
	[ $? -ne 0 ] && return 1

	# install the list of authors
	install -D -m644 AUTHORS $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/AUTHORS
	[ $? -ne 0 ] && return 1
	install -D -m644 THANKS $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/THANKS
	[ $? -ne 0 ] && return 1

	return 0
}
