#!/bin/sh

PKG_NAME="flac"
PKG_VER="1.2.1"
PKG_REV="1"
PKG_DESC="FLAC codec library"
PKG_CAT="Multimedia"
PKG_DEPS="+libogg"

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.gz ] && return 0
	# download the sources tarball
	download_file http://downloads.xiph.org/releases/flac/$PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xzvf $PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# set the CFLAGS
	sed -i s~'-O3'~"$CFLAGS"~ configure
	[ $? -ne 0 ] && return 1

	# generate a new configure script
	autoconf
	[ $? -ne 0 ] && return 1

	# configure the package
	sed -i s/'-O3 '//g configure
	[ $? -ne 0 ] && return 1

	./configure $AUTOTOOLS_BASE_OPTS \
	            --disable-static \
	            --enable-shared \
	            --disable-debug \
	            --disable-thorough-tests \
	            --disable-xmms-plugin
	[ $? -ne 0 ] && return 1

	# fix a missing include issue
	sed -i s/'#include <stdlib.h>'/'&\n#include <string.h>'/ examples/cpp/encode/file/main.cpp
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# install the license and the list of authors
	mkdir -p $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME
	[ $? -ne 0 ] && return 1
	cat README | head -16 | sed -e s/'^...'//g -e s/\*//g > $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/COPYING
	[ $? -ne 0 ] && return 1
	chmod 644 $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/COPYING
	[ $? -ne 0 ] && return 1
	install -D -m644 AUTHORS $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/AUTHORS
	[ $? -ne 0 ] && return 1

	return 0
}
