#!/bin/sh

PKG_NAME="angband"
PKG_VER="3.3.2"
PKG_REV="1"
PKG_DESC="Single-player dungeon exploration game"
PKG_CAT="Fun"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-v$PKG_VER.tar.gz ] && return 0
	# download the sources tarball
	download_file http://rephial.org/downloads/3.3/$PKG_NAME-v$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xzvf $PKG_NAME-v$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-v$PKG_VER

	autoconf
	# configure the package
	./configure $AUTOTOOLS_BASE_OPTS \
	            --with-configpath=/$CONF_DIR/$PKG_NAME \
	            --with-varpath=/$VAR_DIR/$PKG_NAMEl \
	            --disable-gtk \
	            --enable-curses \
	            --disable-x11 \
	            --disable-sdl \
	            --disable-test \
	            --disable-stats \
	            --disable-sdl-mixer \
	            --disable-sdltest \
	            --with-x
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	cp -p install-sh lib
	[ $? -ne 0 ] && return 1
	cp -p install-sh lib/xtra
	[ $? -ne 0 ] && return 1
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# move the icon to the pixmaps directory
	mkdir -p $INSTALL_DIR/$PIXMAP_DIR
	[ $? -ne 0 ] && return 1
	mv $INSTALL_DIR/$SHARE_DIR/$PKG_NAME/xtra/icon/att-128.png $INSTALL_DIR/$PIXMAP_DIR/angband.png
	[ $? -ne 0 ] && return 1

	# remove unneeded stuff
	rm -rf $INSTALL_DIR/$SHARE_DIR/$PKG_NAME/xtra
	[ $? -ne 0 ] && return 1

	# add a menu entry
	mkdir -p $INSTALL_DIR/$DESKTOP_DIR
	[ $? -ne 0 ] && return 1
	cat << END > $INSTALL_DIR/$DESKTOP_DIR/angband.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Angband dungeon exploration game
Icon=angband.png
Comment=Angband dungeon exploration game
Exec=urxvt -title Angband -e angband
Terminal=false
Type=Application
Categories=Game;AdventureGame;
GenericName=Angband dungeon exploration game
END
	[ $? -ne 0 ] && return 1
	chmod 644 $INSTALL_DIR/$DESKTOP_DIR/angband.desktop
	[ $? -ne 0 ] && return 1

	# install the license and the list of credits
	install -D -m644 copying.txt $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/copying.txt
	[ $? -ne 0 ] && return 1
	install -D -m644 thanks.txt $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/thanks.txt
	[ $? -ne 0 ] && return 1

	return 0
}
