#!/bin/sh

PKG_NAME="centerim"
PKG_VER="4.22.10"
PKG_REV="1"
PKG_DESC="Multi-protocol instant messaging client"
PKG_CAT="Internet"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.gz ] && return 0
	# download the sources tarball
	download_file http://centerim.org/download/releases/$PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xzvf $PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# configure the package
	./configure $AUTOTOOLS_BASE_OPTS \
	            --disable-irc \
	            --disable-rss \
	            --disable-lj \
	            --with-fribidi \
	            --with-ssl \
	            --without-libjpeg \
	            --without-libotr \
	            --without-libXss
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# add a menu entry
	mkdir -p $INSTALL_DIR/$DESKTOP_DIR
	[ $? -ne 0 ] && return 1
	cat << END > $INSTALL_DIR/$DESKTOP_DIR/centerim.desktop
[Desktop Entry]
Encoding=UTF-8
Name=CenterIM instant messenger
Icon=chat16.xpm
Comment=CenterIM instant messenger
Exec=urxvt -title CenterIM -e centerim
Terminal=false
Type=Application
Categories=Network;InstantMessaging;Chat;
GenericName=CenterIM instant messenger
END
	[ $? -ne 0 ] && return 1
	chmod 644 $INSTALL_DIR/$DESKTOP_DIR/centerim.desktop
	[ $? -ne 0 ] && return 1

	# install the list of authors
	install -D -m644 AUTHORS $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/AUTHORS
	[ $? -ne 0 ] && return 1

	return 0
}
