#!/bin/sh

PKG_NAME="dejavu-fonts-ttf"
PKG_VER="2.33"
PKG_REV="1"
PKG_DESC="A fork of the Bitstream Vera fonts"
PKG_CAT="core"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.bz2 ] && return 0
	# download the sources tarball
	download_file http://sourceforge.net/projects/dejavu/files/dejavu/$PKG_VER/$PKG_NAME-$PKG_VER.tar.bz2
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xjvf $PKG_NAME-$PKG_VER.tar.bz2
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	return 0
}

package() {
	# install the fonts
	mkdir -p $INSTALL_DIR/$SHARE_DIR/fonts
	[ $? -ne 0 ] && return 1
	mv ttf $INSTALL_DIR/$SHARE_DIR/fonts/TTF
	[ $? -ne 0 ] && return 1

	# install the configuration
	mkdir -p $INSTALL_DIR/$CONF_DIR/fonts
	[ $? -ne 0 ] && return 1
	mv fontconfig $INSTALL_DIR/$CONF_DIR/fonts/conf.avail
	[ $? -ne 0 ] && return 1

	# apply the configuration
	mkdir -p $INSTALL_DIR/etc/fonts/conf.d
	[ $? -ne 0 ] && return 1
	for i in $INSTALL_DIR/$CONF_DIR/fonts/conf.avail/*
	do
		name="$(basename $i)"
		ln -s ../../../$CONF_DIR/fonts/conf.avail/$name $INSTALL_DIR/etc/fonts/conf.d/$name
		[ $? -ne 0 ] && return 1
	done

	# add the post-install script
	echo -n "#!/bin/sh
	
mkfontscale ./$SHARE_DIR/fonts/TTF
mkfontdir ./$SHARE_DIR/fonts/TTF
[ \"\$(pwd)\" = \"/\" ] && fc-cache -fv" > $INSTALL_DIR/post_install.sh
	[ $? -ne 0 ] && return 1
	chmod 755 $INSTALL_DIR/post_install.sh
	[ $? -ne 0 ] && return 1
	
	# install the license and the list of authors
	install -D -m644 LICENSE $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/LICENSE
	[ $? -ne 0 ] && return 1
	install -D -m644 AUTHORS $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/AUTHORS
	[ $? -ne 0 ] && return 1

	return 0
}
