#!/bin/sh

PKG_NAME="groff"
PKG_VER="1.21"
PKG_REV="1"
PKG_DESC="Text formatting tool"
PKG_CAT="Document"
PKG_DEPS=""

# the default paper size
PAPER_SIZE="A4"

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.gz ] && return 0
	# download the sources tarball
	download_file http://ftp.gnu.org/gnu/groff/$PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xzvf $PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# configure the package
	PAGE=$PAPER_SIZE ./configure $AUTOTOOLS_BASE_OPTS \
	                             --without-x
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# add required symlinks
	ln -s eqn $INSTALL_DIR/$BIN_DIR/geqn
	[ $? -ne 0 ] && return 1
	ln -s tbl $INSTALL_DIR/$BIN_DIR/gtbl
	[ $? -ne 0 ] && return 1

	# add the default paper size file
	mkdir -p $INSTALL_DIR/$CONF_DIR
	[ $? -ne 0 ] && return 1
	echo $PAPER_SIZE > $INSTALL_DIR/$CONF_DIR/papersize
	[ $? -ne 0 ] && return 1
	chmod 644 $INSTALL_DIR/$CONF_DIR/papersize
	[ $? -ne 0 ] && return 1

	# install the licenses file
	install -D -m644 LICENSES $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/LICENSES
	[ $? -ne 0 ] && return 1

	return 0
}
