#!/bin/sh

PKG_NAME="gtk2_prefs"
PKG_VER="0.4.1"
PKG_REV="1"
PKG_DESC="A GTK+ 2 theme switcher"
PKG_CAT="Desktop"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.bz2 ] && return 0
	# download the sources tarball
	download_file http://downloads.sourceforge.net/gtk-win/$PKG_NAME-$PKG_VER.tar.bz2
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xjvf $PKG_NAME-$PKG_VER.tar.bz2
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# add a missing header
	sed -i s/'#include <stdlib.h>'/'&\n#include <string.h>'/ src/main.cpp
	[ $? -ne 0 ] && return 1

	# generate a configure script
	./autogen.sh
	[ $? -ne 0 ] && return 1

	# configure the package
	./configure $AUTOTOOLS_BASE_OPTS
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# add a menu entry
	mkdir -p $INSTALL_DIR/$DESKTOP_DIR
	[ $? -ne 0 ] && return 1
	cat << END > $INSTALL_DIR/$DESKTOP_DIR/gtk2_prefs.desktop
[Desktop Entry]
Encoding=UTF-8
Name=gtk2_prefs GTK+ theme chooser
Icon=wizard16.xpm
Comment=gtk2_prefs GTK+ theme chooser
Exec=gtk2_prefs
Terminal=false
Type=Application
Categories=Settings;DesktopSettings;
GenericName=gtk2_prefs GTK+ theme chooser
END
	[ $? -ne 0 ] && return 1
	chmod 644 $INSTALL_DIR/$DESKTOP_DIR/gtk2_prefs.desktop
	[ $? -ne 0 ] && return 1

	# install the list of authors
	install -D -m644 AUTHORS $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/AUTHORS
	[ $? -ne 0 ] && return 1

	return 0
}
