#!/bin/sh

PKG_NAME="htop"
PKG_VER="1.0"
PKG_REV="1"
PKG_DESC="Interactive process viewer"
PKG_CAT="System"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.gz ] && return 0
	# download the sources tarball
	download_file http://downloads.sourceforge.net/project/htop/htop/$PKG_VER/$PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xzvf $PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# configure the package
	./configure $AUTOTOOLS_BASE_OPTS \
	            --disable-openvz \
	            --disable-vserver
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# move the icon to the right location
	if [ "$PIXMAP_DIR" != "$SHARE_DIR/pixmaps" ]
	then
		mkdir -p $INSTALL_DIR/$PIXMAP_DIR
		[ $? -ne 0 ] && return 1
		mv $INSTALL_DIR/$SHARE_DIR/pixmaps/htop.png $INSTALL_DIR/$PIXMAP_DIR
		[ $? -ne 0 ] && return 1
		rm -rf $INSTALL_DIR/$SHARE_DIR/pixmaps
		[ $? -ne 0 ] && return 1
	fi

	# remove the old menu entry
	if [ "$DESKTOP_DIR" != "$SHARE_DIR/applications" ]
	then
		rm -rf $INSTALL_DIR/$SHARE_DIR/applications
		[ $? -ne 0 ] && return 1
		mkdir -p $INSTALL_DIR/$DESKTOP_DIR
		[ $? -ne 0 ] && return 1
	fi

	# replace the menu entry
	cat << END > $INSTALL_DIR/$DESKTOP_DIR/htop.desktop
[Desktop Entry]
Encoding=UTF-8
Name=htop process viewer
Icon=htop.png
Comment=htop process viewer
Exec=urxvt -title htop -e htop
Terminal=false
Type=Application
Categories=System;Monitor;
GenericName=htop process viewer
END
	[ $? -ne 0 ] && return 1
	chmod 644 $INSTALL_DIR/$DESKTOP_DIR/htop.desktop
	[ $? -ne 0 ] && return 1

	# install the list of authors
	install -D -m644 AUTHORS $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/AUTHORS
	[ $? -ne 0 ] && return 1

	return 0
}
