#!/bin/sh

PKG_NAME="irssi"
PKG_VER="0.8.15"
PKG_REV="1"
PKG_DESC="IRC client"
PKG_CAT="Internet"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.bz2 ] && return 0
	# download the sources tarball
	download_file http://irssi.org/files/$PKG_NAME-$PKG_VER.tar.bz2
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xjvf $PKG_NAME-$PKG_VER.tar.bz2
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# configure the package
	./configure $AUTOTOOLS_BASE_OPTS \
	            --enable-ipv6 \
	            --enable-ssl \
	            --without-socks \
	            --with-textui \
	            --without-bot \
	            --without-proxy \
	            --without-terminfo \
	            --with-perl=no
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# install the icon
	install -D -m644 irssi-icon.png $INSTALL_DIR/$PIXMAP_DIR/irssi.png
	[ $? -ne 0 ] && return 1

	# add a menu entry
	mkdir -p $INSTALL_DIR/$DESKTOP_DIR
	[ $? -ne 0 ] && return 1
	cat << END > $INSTALL_DIR/$DESKTOP_DIR/irssi.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Irssi IRC client
Icon=irssi.png
Comment=Irssi IRC client
Exec=urxvt -title Irssi -e irssi
Terminal=false
Type=Application
Categories=Network;InstantMessaging;Chat;
GenericName=Irssi IRC client
END
	[ $? -ne 0 ] && return 1
	chmod 644 $INSTALL_DIR/$DESKTOP_DIR/irssi.desktop
	[ $? -ne 0 ] && return 1

	# install the list of authors
	install -D -m644 AUTHORS $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/AUTHORS
	[ $? -ne 0 ] && return 1
	head -n 2 COPYING > $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/COPYING
	[ $? -ne 0 ] && return 1
	chmod 644 $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/COPYING
	[ $? -ne 0 ] && return 1

	return 0
}
