#!/bin/sh

PKG_NAME="less"
PKG_VER="444"
PKG_REV="1"
PKG_DESC="Text viewer"
PKG_CAT="Document"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.gz ] && return 0
	# download the sources tarball
	download_file http://www.greenwoodsoftware.com/less/$PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xzvf $PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# configure the package
	./configure $AUTOTOOLS_BASE_OPTS \
	            --with-secure \
	            --with-regex=posix \
	            --with-editor=defaulttexteditor
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# remove lessecho and lesskey
	rm -f $INSTALL_DIR/$BIN_DIR/lessecho \
	      $INSTALL_DIR/$BIN_DIR/lesskey \
	      $INSTALL_DIR/$MAN_DIR/man1/lessecho.1 \
	      $INSTALL_DIR/$MAN_DIR/man1/lesskey.1
	[ $? -ne 0 ] && return 1

	# create a backwards-compatibility symlink
	if [ "usr/bin" != "$BIN_DIR" ]
	then
		mkdir -p $INSTALL_DIR/usr/bin
		[ $? -ne 0 ] && return 1
		ln -s ../../$BIN_DIR/less $INSTALL_DIR/usr/bin/less
		[ $? -ne 0 ] && return 1
	fi

	# install the license
	install -D -m644 LICENSE $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/LICENSE
	[ $? -ne 0 ] && return 1

	return 0
}
