#!/bin/sh

PKG_NAME="links"
PKG_VER="2.5"
PKG_REV="1"
PKG_DESC="Text web browser"
PKG_CAT="Internet"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.bz2 ] && return 0
	# download the sources tarball
	download_file http://links.twibright.com/download/$PKG_NAME-$PKG_VER.tar.bz2
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xjvf $PKG_NAME-$PKG_VER.tar.bz2
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# generate a new configure script
	autoconf
	[ $? -ne 0 ] && return 1

	# configure the package
	./configure $AUTOTOOLS_BASE_OPTS \
	            --enable-debuglevel=0 \
	            --disable-graphics \
	            --disable-utf8 \
	            --without-gpm \
	            --with-ssl \
	            --with-zlib \
	            --with-bzip2 \
	            --with-lzma \
	            --without-svgalib \
	            --without-x \
	            --without-fb \
	            --without-directfb \
	            --without-pmshell \
	            --without-atheos \
	            --without-x \
	            --disable-png-pkgconfig \
	            --without-libjpeg \
	            --without-libtiff
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# install the icon
	install -D -m644 graphics/links.xpm $INSTALL_DIR/$PIXMAP_DIR/links.xpm
	[ $? -ne 0 ] && return 1

	# add a menu entry
	mkdir -p $INSTALL_DIR/$DESKTOP_DIR
	[ $? -ne 0 ] && return 1
	cat << END > $INSTALL_DIR/$DESKTOP_DIR/links.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Links web browser
Icon=links.xpm
Comment=Links web browser
Exec=urxvt -title Links -e links
Terminal=false
Type=Application
MimeType=text/html
Categories=Network;WebBrowser;
GenericName=Links web browser
END
	[ $? -ne 0 ] && return 1
	chmod 644 $INSTALL_DIR/$DESKTOP_DIR/links.desktop
	[ $? -ne 0 ] && return 1

	# install the list of authors
	install -D -m644 AUTHORS $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/AUTHORS
	[ $? -ne 0 ] && return 1

	return 0
}
