#!/bin/sh

PKG_NAME="man"
PKG_VER="1.6g"
PKG_REV="1"
PKG_DESC="Manual page viewer"
PKG_CAT="Help"
PKG_DEPS="+less,+groff"

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.gz ] && return 0
	# download the sources tarball
	download_file http://primates.ximian.com/~flucifredi/man/$PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xzvf $PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# add the -R flag to less, so escape sequences are handled properly
	sed -i s/'-is'/'&R'/g configure
	[ $? -ne 0 ] && return 1

	# configure the package
	./configure -confdir=/$CONF_DIR \
	            +fhs \
	            +lang en
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	for i in man apropos
	do
		install -D -m755 src/$i $INSTALL_DIR/$BIN_DIR/$i
		[ $? -ne 0 ] && return 1
	done
	for i in whatis makewhatis
	do
		install -D -m755 src/$i $INSTALL_DIR/$SBIN_DIR/$i
		[ $? -ne 0 ] && return 1
	done

	for i in man apropos whatis
	do
		install -D -m644 man/en/$i.1 $INSTALL_DIR/$MAN_DIR/man1/$i
		[ $? -ne 0 ] && return 1
	done

	# add /opt/share/man to the man pages search path
	sed -i s~'^MANPATH	/usr/share/man'~'&\nMANPATH	/opt/share/man'~ src/man.conf
	[ $? -ne 0 ] && return 1

	install -D -m644 src/man.conf $INSTALL_DIR/$CONF_DIR/man.conf
	[ $? -ne 0 ] && return 1

	return 0
}
