#!/bin/sh

PKG_NAME="moon-buggy"
PKG_VER="1.0.51"
PKG_REV="1"
PKG_DESC="A simple moon-buggy racing game"
PKG_CAT="Fun"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.gz ] && return 0
	# download the sources tarball
	download_file http://m.seehuhn.de/programs/$PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xzvf $PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# generate a new configure script
	autoconf
	[ $? -ne 0 ] && return 1

	# configure the package
	./configure $AUTOTOOLS_BASE_OPTS \
	            --sharedstatedir=/$VAR_DIR/tmp
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# install the icon
	install -D -m644 moon-buggy.png $INSTALL_DIR/$PIXMAP_DIR/moon-buggy.png
	[ $? -ne 0 ] && return 1
	
	# add a menu entry
	mkdir -p $INSTALL_DIR/$DESKTOP_DIR
	[ $? -ne 0 ] && return 1
	cat << END > $INSTALL_DIR/$DESKTOP_DIR/moon-buggy.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Moon-buggy arcade game
Icon=moon-buggy.png
Comment=Moon-buggy arcade game
Exec=urxvt -title Moon-buggy -e moon-buggy
Terminal=false
Type=Application
Categories=Game;ArcadeGame;
GenericName=Moon-buggy arcade game
END
	[ $? -ne 0 ] && return 1
	chmod 644 $INSTALL_DIR/$DESKTOP_DIR/moon-buggy.desktop
	[ $? -ne 0 ] && return 1

	# install the list of authors
	install -D -m644 AUTHORS $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/AUTHORS
	[ $? -ne 0 ] && return 1
	install -D -m644 THANKS $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/THANKS
	[ $? -ne 0 ] && return 1

	return 0
}
