#!/bin/sh

PKG_NAME="nano"
PKG_VER="2.2.6"
PKG_REV="1"
PKG_DESC="Clone of the Pico text editor"
PKG_CAT="Document"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.gz ] && return 0
	# download the sources tarball
	download_file http://www.nano-editor.org/dist/v2.2/$PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xzvf $PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# configure the package
	./configure $AUTOTOOLS_BASE_OPTS \
	            --disable-debug \
	            --disable-extra \
	            --disable-browser \
	            --disable-mouse \
	            --disable-operatingdir \
	            --enable-utf8 \
	            --without-slang
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# add a menu entry
	mkdir -p $INSTALL_DIR/$DESKTOP_DIR
	[ $? -ne 0 ] && return 1
	cat << END > $INSTALL_DIR/$DESKTOP_DIR/nano.desktop
[Desktop Entry]
Encoding=UTF-8
Name=nano text editor
Icon=mini-doc.xpm
Comment=nano text editor
Exec=urxvt -title "GNU nano" -e nano
Terminal=false
Type=Application
MimeType=text/plain
Categories=Utility;TextEditor;
GenericName=nano text editor
END
	[ $? -ne 0 ] && return 1
	chmod 644 $INSTALL_DIR/$DESKTOP_DIR/nano.desktop
	[ $? -ne 0 ] && return 1

	# install the list of authors and the credits
	install -D -m644 AUTHORS $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/AUTHORS
	[ $? -ne 0 ] && return 1
	install -D -m644 THANKS $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/THANKS
	[ $? -ne 0 ] && return 1

	return 0
}
