#!/bin/sh

PKG_NAME="ncdu"
PKG_VER="1.8"
PKG_REV="1"
PKG_DESC="Disk usage analyzer"
PKG_CAT="system"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.gz ] && return 0
	# download the sources tarball
	download_file http://dev.yorhel.nl/download/$PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xzvf $PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# configure the package
	./configure $AUTOTOOLS_BASE_OPTS
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# add a menu entry
	mkdir -p $INSTALL_DIR/$DESKTOP_DIR
	[ $? -ne 0 ] && return 1
	cat << END > $INSTALL_DIR/$DESKTOP_DIR/nano.desktop
[Desktop Entry]
Encoding=UTF-8
Name=ncdu disk usage analyzer
Icon=mini-fdisk.xpm
Comment=ncdu disk usage analyzer
Exec=urxvt -title ncdu -e ncdu
Terminal=false
Type=Application
Categories=Utility;Filesystem;
GenericName=ncdu disk usage analyzer
END
	[ $? -ne 0 ] && return 1
	chmod 644 $INSTALL_DIR/$DESKTOP_DIR/nano.desktop
	[ $? -ne 0 ] && return 1

	# install the license and the list of authors
	install -D -m644 COPYING $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/COPYING
	[ $? -ne 0 ] && return 1
	install -D -m644 AUTHORS $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/AUTHORS
	[ $? -ne 0 ] && return 1

	return 0
}
