#!/bin/sh

PKG_NAME="simpleburn"
PKG_VER="1.6.3"
PKG_REV="1"
PKG_DESC="A simple CD/DVD burning and ripping application"
PKG_CAT="Multimedia"
PKG_DEPS="+cdrkit"

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.bz2 ] && return 0
	# download the sources tarball
	download_file http://simpleburn.tuxfamily.org/IMG/bz2/$PKG_NAME-$PKG_VER.tar.bz2
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xjvf $PKG_NAME-$PKG_VER.tar.bz2
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# configure the package
	CFLAGS="$CFLAGS $(pkg-config --libs --cflags gtk+-2.0)" \
	cmake . \
	      -DCMAKE_INSTALL_PREFIX=/$BASE_INSTALL_PREFIX \
	      -DDETECTION=UDEV \
	      -DBURNING=CDRTOOLS
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# remove unneeded documentation
	rm -f $INSTALL_DIR/$DOC_DIR/$PKG_NAME-$PKG_VER
	[ $? -ne 0 ] && return 1

	# create a symlink to the icon
	if [ "$PIXMAP_DIR" != "$SHARE_DIR/pixmaps" ]
	then
		mkdir -p $INSTALL_DIR/$PIXMAP_DIR
		[ $? -ne 0 ] && return 1
		ln -s /$SHARE_DIR/pixmaps/simpleburn.png $INSTALL_DIR/$PIXMAP_DIR
		[ $? -ne 0 ] && return 1
	fi

	# remove the old menu entry
	if [ "$DESKTOP_DIR" != "$SHARE_DIR/applications" ]
	then
		rm -rf $INSTALL_DIR/$SHARE_DIR/applications
		[ $? -ne 0 ] && return 1
		mkdir -p $INSTALL_DIR/$DESKTOP_DIR
		[ $? -ne 0 ] && return 1
	fi

	# add a menu entry
	cat << END > $INSTALL_DIR/$DESKTOP_DIR/simpleburn.desktop
[Desktop Entry]
Encoding=UTF-8
Name=SimpleBurn CD/DVD burning
Icon=simpleburn.png
Comment=SimpleBurn CD/DVD burning
Exec=simpleburn
Terminal=false
Type=Application
Categories=AudioVideo;AudioVideo;
GenericName=SimpleBurn CD/DVD burning
END
	[ $? -ne 0 ] && return 1
	chmod 644 $INSTALL_DIR/$DESKTOP_DIR/simpleburn.desktop
	[ $? -ne 0 ] && return 1

	# install the license and the list of authors
	install -D -m644 doc/LICENSE-EN $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/LICENSE-EN
	[ $? -ne 0 ] && return 1
	install -D -m644 doc/AUTHORS $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/AUTHORS
	[ $? -ne 0 ] && return 1

	return 0
}
