#!/bin/sh

PKG_NAME="stalonetray"
PKG_VER="0.8.1"
PKG_REV="1"
PKG_DESC="Standlone system tray"
PKG_CAT="Desktop"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.bz2 ] && return 0
	# download the sources tarball
	download_file http://downloads.sourceforge.net/project/stalonetray/stalonetray/$PKG_NAME-$PKG_VER/$PKG_NAME-$PKG_VER.tar.bz2
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xjvf $PKG_NAME-$PKG_VER.tar.bz2
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# make it vertical and transparent by default
	sed -e s/'settings.transparent		= 0;'/'settings.transparent		= 1;'/ \
	    -e s/'settings.vertical			= 0;'/'settings.vertical			= 1;'/ \
	    -e s/'settings.wnd_layer			= NULL;'/'settings.wnd_layer			= _NET_WM_STATE_BELOW;'/ \
	    -i src/settings.c
	[ $? -ne 0 ] && return 1

	# configure the package
	./configure $AUTOTOOLS_BASE_OPTS \
	            --disable-native-kde \
	            --disable-debug \
	            --disable-dump-win-info
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# install the example configuration file
	install -D -m644 stalonetrayrc.sample $INSTALL_DIR/$CONF_DIR/stalonetrayrc
	[ $? -ne 0 ] && return 1

	# make it auto-start
	mkdir -p $INSTALL_DIR/root/Startup
	[ $? -ne 0 ] && return 1
	echo -n "#!/bin/dash

exec stalonetray --kludges force_icons_size" > $INSTALL_DIR/root/Startup/stalonetray.sh
	[ $? -ne 0 ] && return 1
	chmod 755 $INSTALL_DIR/root/Startup/stalonetray.sh
	[ $? -ne 0 ] && return 1

	# install the list of authors
	install -D -m644 AUTHORS $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/AUTHORS
	[ $? -ne 0 ] && return 1

	return 0
}
