#!/bin/sh

PKG_NAME="sxiv"
PKG_VER="git$(date +%d%m%Y)"
PKG_REV="1"
PKG_DESC="Simple imlib2-based image viewer"
PKG_CAT="Graphic"
PKG_DEPS="+yad,+imlib2"

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.xz ] && return 0
	# download the sources
	git clone --depth 1 git://github.com/muennich/sxiv.git $PKG_NAME-$PKG_VER
	[ $? -ne 0 ] && return 1

	# create a sources tarball
	tar -c $PKG_NAME-$PKG_VER | xz -9 > $PKG_NAME-$PKG_VER.tar.xz
	[ $? -ne 0 ] && return 1

	# clean up
	rm -rf $PKG_NAME-$PKG_VER
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xJvf $PKG_NAME-$PKG_VER.tar.xz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# configure the package
	sed -e s~'-O2'~"$CFLAGS"~ \
	    -e s~'/usr/local'~"/$BASE_INSTALL_PREFIX"~ \
	    -e s~'^LDFLAGS =.*'~"LDFLAGS = $LDFLAGS"~ \
	    -i Makefile
	[ $? -ne 0 ] && return 1

	# generate config.h
	make -j $BUILD_THREADS config.h
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# add a wrapper which uses Yad for a file selection dialog
	echo -n '#!/bin/dash
choice="$(yad --file \
              --window-icon=/usr/local/lib/X11/mini-icons/mini-palette.xpm \
              --title=sxiv --width 500 --height 300)"
[ $? -eq 1 ] && exit 0
exec sxiv "$choice"' >  $INSTALL_DIR/$BIN_DIR/sxiv_shell
	[ $? -ne 0 ] && return 1
	chmod 755 $INSTALL_DIR/$BIN_DIR/sxiv_shell
	[ $? -ne 0 ] && return 1

	# add a menu entry
	mkdir -p $INSTALL_DIR/$DESKTOP_DIR
	[ $? -ne 0 ] && return 1
	echo -n "[Desktop Entry]
Encoding=UTF-8
Name=sxiv image viewer
Icon=mini-palette.xpm
Comment=sxiv image viewer
Exec=sxiv_shell
Terminal=false
Type=Application
Categories=Graphics;2DGraphics;RasterGraphics;
GenericName=sxiv image viewer" > $INSTALL_DIR/$DESKTOP_DIR/sxiv.desktop
	[ $? -ne 0 ] && return 1
	chmod 644 $INSTALL_DIR/$DESKTOP_DIR/sxiv.desktop
	[ $? -ne 0 ] && return 1

	return 0
}
