#!/bin/sh

PKG_NAME="unnethack"
PKG_VER="3.6.1-20120205"
PKG_REV="1"
PKG_DESC="A variant of the roguelike game NetHack"
PKG_CAT="Fun"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.gz ] && return 0
	# download the sources tarball
	download_file http://downloads.sourceforge.net/project/unnethack/unnethack/3.6.1/$PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xzvf $PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# configure the package
	./configure $AUTOTOOLS_BASE_OPTS \
	            --docdir=/$DOC_DIR \
	            --disable-dummy-graphics \
	            --enable-curses-graphics \
	            --disable-tty-graphics \
	            --disable-mswin-graphics \
	            --enable-wizmode=root \
	            --with-compression="$(which xz)" \
	            --with-owner=root \
	            --with-group=root \
	            --with-gamesdir=/$SHARE_DIR/$PKG_NAME \
	            --with-bonesdir=/$VAR_DIR/$PKG_NAME/bones \
	            --with-savesdir=/$VAR_DIR/$PKG_NAME/saves \
	            --with-leveldir=/$VAR_DIR/$PKG_NAME/level
	[ $? -ne 0 ] && return 1

	# build the package
	make -j $BUILD_THREADS
	[ $? -ne 0 ] && return 1
	make -j $BUILD_THREADS manpages
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# install the man pages
	for i in doc/*.6
	do
		install -D -m644 $i $INSTALL_DIR/$MAN_DIR/man6/$(basename $i)
		[ $? -ne 0 ] && return 1
	done

	# install the icon
	install -D -m644 win/unsupported/X11/nh_icon.xpm $INSTALL_DIR/$PIXMAP_DIR/unnethack.xpm
	[ $? -ne 0 ] && return 1

	# add a menu entry
	mkdir -p $INSTALL_DIR/$DESKTOP_DIR
	[ $? -ne 0 ] && return 1
	cat << END > $INSTALL_DIR/$DESKTOP_DIR/unnethack.desktop
[Desktop Entry]
Encoding=UTF-8
Name=UnNetHack roguelike game
Icon=unnethack.xpm
Comment=UnNetHack roguelike game
Exec=urxvt -title UnNetHack -e unnethack
Terminal=false
Type=Application
Categories=Game;AdventureGame;
GenericName=UnNetHack roguelike game
END
	[ $? -ne 0 ] && return 1
	chmod 644 $INSTALL_DIR/$DESKTOP_DIR/unnethack.desktop
	[ $? -ne 0 ] && return 1

	# install the license
	install -D -m644 dat/license $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/license
	[ $? -ne 0 ] && return 1

	return 0
}
