#!/bin/sh

PKG_NAME="zathura"
PKG_VER="0.0.8.5"
PKG_REV="1"
PKG_DESC="PDF viewer"
PKG_CAT="Document"
PKG_DEPS=""

download() {
	[ -f $PKG_NAME-$PKG_VER.tar.gz ] && return 0
	# download the sources tarball
	download_file http://pwmt.org/download/$PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1
	return 0
}

build() {
	# extract the sources tarball
	tar -xzvf $PKG_NAME-$PKG_VER.tar.gz
	[ $? -ne 0 ] && return 1

	cd $PKG_NAME-$PKG_VER

	# build the package
	make -j $BUILD_THREADS PREFIX=/$BASE_INSTALL_PREFIX
	[ $? -ne 0 ] && return 1

	return 0
}

package() {
	# install the package
	make PREFIX=/$BASE_INSTALL_PREFIX DESTDIR=$INSTALL_DIR install
	[ $? -ne 0 ] && return 1

	# remove the old menu entry
	if [ "$DESKTOP_DIR" != "$SHARE_DIR/applications" ]
	then
		rm -rf $INSTALL_DIR/$SHARE_DIR/applications
		[ $? -ne 0 ] && return 1
		mkdir -p $INSTALL_DIR/$DESKTOP_DIR
		[ $? -ne 0 ] && return 1
	fi

	# replace the menu entry
	cat << END > $INSTALL_DIR/$DESKTOP_DIR/zathura.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Zathura PDF viewer
Icon=mini-doc.xpm
Comment=Zathura PDF viewer
Exec=zathura
Terminal=false
Type=Application
MimeType=application/pdf;
Categories=Viewer;Presentation;Office;
GenericName=Zathura PDF viewer
END
	[ $? -ne 0 ] && return 1
	chmod 644 $INSTALL_DIR/$DESKTOP_DIR/zathura.desktop
	[ $? -ne 0 ] && return 1

	# add the post-install script
	echo '#!/bin/sh

if [ -d ./root/Choices/MIME-types ]
then
	echo "Setting Zathura as the default PDF viewer"

	echo "#!/bin/sh
exec zathura \"\$1\"" > ./root/Choices/MIME-types/application_pdf
	chmod 755 ./root/Choices/MIME-types/application_pdf
fi' > $INSTALL_DIR/post_install.sh
	[ $? -ne 0 ] && return 1
	chmod 755 $INSTALL_DIR/post_install.sh
	[ $? -ne 0 ] && return 1

	# install the license
	install -D -m644 LICENSE $INSTALL_DIR/$LEGAL_DIR/$PKG_NAME/LICENSE
	[ $? -ne 0 ] && return 1

	return 0
}
